pub struct WitchcraftEnvelopeV1 { /* private fields */ }Expand description
Wraps a log entry with metadata on where it is coming from and the source service that generated it.
Implementations
Sourceimpl WitchcraftEnvelopeV1
impl WitchcraftEnvelopeV1
Sourcepub fn deployment(&self) -> &str
pub fn deployment(&self) -> &str
Color or other codename for the customer infra
Sourcepub fn environment(&self) -> &str
pub fn environment(&self) -> &str
prod/staging/integration etc.
Sourcepub fn environment_id(&self) -> &str
pub fn environment_id(&self) -> &str
Skylab environment ID
Sourcepub fn service_id(&self) -> &str
pub fn service_id(&self) -> &str
Skylab service ID
Sourcepub fn product_version(&self) -> &str
pub fn product_version(&self) -> &str
Artifact semantic version
Sourcepub fn payload(&self) -> &Any
pub fn payload(&self) -> &Any
One of the Witchcraft log types; see witchcraft-api for details.
Sourcepub fn apollo_entity_id(&self) -> &str
pub fn apollo_entity_id(&self) -> &str
Apollo entity id
Sourcepub fn apollo_environment_id(&self) -> &str
pub fn apollo_environment_id(&self) -> &str
Apollo environment id